==> blesta-5.10.2.zip: blesta/plugins/domains/language/sv_se/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Välj automatiskt --';
$lang['AdminMain.edit.title_basic_options'] = 'Grundläggande alternativ';
$lang['AdminMain.edit.title_actions'] = 'Åtgärder';
$lang['AdminMain.edit.title_domain_information'] = 'Domäninformation';
$lang['AdminMain.edit.term_years'] = '%1$s År';
$lang['AdminMain.edit.term_year'] = '%1$s År';
$lang['AdminMain.edit.term_months'] = '%1$s Månader';
$lang['AdminMain.edit.term_month'] = '%1$s Månad';
$lang['AdminMain.edit.term_weeks'] = '%1$s Veckor';
$lang['AdminMain.edit.term_week'] = '%1$s Vecka';
$lang['AdminMain.edit.term_days'] = '%1$s Dagar';
$lang['AdminMain.edit.term_day'] = '%1$s Dag';
$lang['AdminMain.edit.text_date_canceled'] = 'Datum för avbokning:';
$lang['AdminMain.edit.text_date_suspended'] = 'Datum för avstängning:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Datum för senaste förnyelse:';
$lang['AdminMain.edit.text_never'] = 'Aldrig';
$lang['AdminMain.edit.text_date_expires'] = 'Datumet löper ut:';
$lang['AdminMain.edit.text_date_renews'] = 'Datumet förnyas:';
$lang['AdminMain.edit.text_date_added'] = 'Skapat datum:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Registrerade år:';
$lang['AdminMain.edit.text_registrar'] = 'Registrator:';
$lang['AdminMain.edit.text_domain'] = 'Domän:';
$lang['AdminMain.edit.field_edit_service'] = 'Redigera tjänst';
$lang['AdminMain.edit.field_activate'] = 'Aktivera';
$lang['AdminMain.edit.field_submit'] = 'Uppdatering';
$lang['AdminMain.edit.field_notify_order'] = 'Skicka e-post med orderbekräftelse när aktiverad';
$lang['AdminMain.edit.field_use_module'] = 'Använd modul';
$lang['AdminMain.edit.field_module'] = 'Modul för registrator';
$lang['AdminMain.edit.field_client'] = 'Kund';
$lang['AdminMain.edit.field_ns5'] = 'Namnserver 5';
$lang['AdminMain.edit.field_ns4'] = 'Namnserver 4';
$lang['AdminMain.edit.field_ns3'] = 'Namnserver 3';
$lang['AdminMain.edit.field_ns2'] = 'Namnserver 2';
$lang['AdminMain.edit.field_ns1'] = 'Namnserver 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Aktivera automatisk förnyelse';
$lang['AdminMain.edit.field_years'] = 'År';
$lang['AdminMain.edit.field_action'] = 'Åtgärder';
$lang['AdminMain.edit.link_viewclient'] = 'Visa kund';
$lang['AdminMain.edit.boxtitle_edit'] = 'Redigera domän: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Kund #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Rabatt:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Sub Totalt:';
$lang['AdminMain.add_confirmation.price'] = 'Pris';
$lang['AdminMain.add_confirmation.qty'] = 'Antal';
$lang['AdminMain.add_confirmation.description'] = 'Beskrivning';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Överföring';
$lang['AdminMain.add_confirmation.type_register'] = 'Registrering';
$lang['AdminMain.add_confirmation.field_edit'] = 'Redigera';
$lang['AdminMain.add_confirmation.field_add'] = 'Lägg till domän';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Uppdatering';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Kupongkod';
$lang['AdminMain.add_confirmation.field_price'] = 'Pris:';
$lang['AdminMain.add_confirmation.field_type'] = 'Typ:';
$lang['AdminMain.add_confirmation.field_years'] = 'År:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domän:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Nej';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ja';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Skicka e-post med orderbekräftelse:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modul för registratorer:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Fakturera inte';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Bifoga till faktura %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Skapa ny faktura';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Faktureringsmetod:';
$lang['AdminMain.add.edit_package_pricing'] = 'Redigera priser';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (förnyas @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Beställning vald';
$lang['AdminMain.add.term_years'] = '%1$s År';
$lang['AdminMain.add.term_year'] = '%1$s År';
$lang['AdminMain.add.term_months'] = '%1$s Månader';
$lang['AdminMain.add.term_month'] = '%1$s Månad';
$lang['AdminMain.add.term_weeks'] = '%1$s Veckor';
$lang['AdminMain.add.term_week'] = '%1$s Vecka';
$lang['AdminMain.add.term_days'] = '%1$s Dagar';
$lang['AdminMain.add.term_day'] = '%1$s Dag';
$lang['AdminMain.add.text_domain_unavailable'] = 'Ej tillgänglig';
$lang['AdminMain.add.text_domain_available'] = 'Tillgänglig';
$lang['AdminMain.add.heading_options'] = 'Alternativ';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domän';
$lang['AdminMain.add.title_registrar_options'] = 'Alternativ för registrator';
$lang['AdminMain.add.title_basic_options'] = 'Grundläggande alternativ';
$lang['AdminMain.add.title_search_results'] = 'Sökresultat';
$lang['AdminMain.add.field_notify_order'] = 'Skicka e-post med orderbekräftelse när aktiverad';
$lang['AdminMain.add.field_use_module'] = 'Tillhandahåll domänen med hjälp av registrarmodulen när den är aktiverad';
$lang['AdminMain.add.field_module'] = 'Modul för registrator';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'År';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Fakturera inte';
$lang['AdminMain.add.field_invoice_method_append'] = 'Lägg till befintlig faktura';
$lang['AdminMain.add.field_invoice_method_create'] = 'Skapa ny faktura';
$lang['AdminMain.add.field_invoice_method'] = 'Faktureringsmetod';
$lang['AdminMain.add.field_submit'] = 'Fortsätta';
$lang['AdminMain.add.field_lookup'] = 'Kontrollera tillgänglighet';
$lang['AdminMain.add.field_add'] = 'Lägg till domän';
$lang['AdminMain.add.field_register'] = 'Register';
$lang['AdminMain.add.field_transfer'] = 'Överföring';
$lang['AdminMain.add.link_viewclient'] = 'Visa kund';
$lang['AdminMain.add.boxtitle_add'] = 'Lägg till domän: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Kund #%1$s';
$lang['AdminMain.index.unparent'] = 'Föräldrafri och återställ priset';
$lang['AdminMain.!error.unsupported_domain'] = 'Domännamnet stöds inte.';
$lang['AdminMain.!success.service_edited'] = 'Domänen har uppdaterats framgångsrikt!';
$lang['AdminMain.!success.domain_add'] = 'Domänen har lagts till framgångsrikt!';
$lang['AdminMain.!success.domain_transfer'] = 'Domänen har överförts framgångsrikt!';
$lang['AdminMain.!success.domain_register'] = 'Domänen har registrerats framgångsrikt!';
$lang['AdminMain.!success.domains_unparented'] = 'De valda domänerna togs bort från sina överordnade tjänster och priset har återställts framgångsrikt!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Domännamn';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Någon';
$lang['AdminMain.domains.action.field_client'] = 'Kund';
$lang['AdminMain.domains.action.field_nameservers'] = 'Namnservrar';
$lang['AdminMain.domains.action.field_years'] = 'År';
$lang['AdminMain.index.field_actionsubmit'] = 'Skicka in';
$lang['AdminMain.index.domain_push_to_client'] = 'Tryck till klient';
$lang['AdminMain.index.update_nameservers'] = 'Uppdatera namnservrar';
$lang['AdminMain.index.domain_renewal'] = 'Förnya domän';
$lang['AdminMain.index.change_auto_renewal'] = 'Ändra förnyelse av bil';
$lang['AdminMain.index.text_off'] = 'Av';
$lang['AdminMain.index.text_on'] = 'På';
$lang['AdminMain.index.text_never'] = 'Aldrig';
$lang['AdminMain.index.no_results'] = 'Det finns inga tjänster med denna status.';
$lang['AdminMain.index.confirm_delete'] = 'Är du säker på att du vill ta bort den här tjänsten?';
$lang['AdminMain.index.option_delete'] = 'Radera';
$lang['AdminMain.index.option_manage'] = 'Hantera';
$lang['AdminMain.index.option_parent'] = 'Förälder';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Ny domän';
$lang['AdminMain.index.category_canceled'] = 'Avbokad';
$lang['AdminMain.index.category_suspended'] = 'Suspenderad';
$lang['AdminMain.index.category_pending'] = 'Pågående';
$lang['AdminMain.index.category_active'] = 'Aktiv';
$lang['AdminMain.index.heading_options'] = 'Alternativ';
$lang['AdminMain.index.heading_datecanceled'] = 'Datum Annullerat';
$lang['AdminMain.index.heading_datesuspended'] = 'Datum uppskjutet';
$lang['AdminMain.index.heading_dateexpires'] = 'Datum som löper ut';
$lang['AdminMain.index.heading_daterenews'] = 'Datum Förnyas';
$lang['AdminMain.index.heading_datecreated'] = 'Skapat datum';
$lang['AdminMain.index.heading_term'] = 'Term';
$lang['AdminMain.index.heading_domain'] = 'Domän';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Tillägg';
$lang['AdminMain.index.boxtitle_domains'] = 'Domäner';
$lang['AdminMain.index.page_title'] = 'Klient #%1$s Domäner';
$lang['AdminMain.!success.domains_pushed'] = 'De valda domänerna har överförts till den nya klienten.';
$lang['AdminMain.!success.update_nameservers'] = 'Domännamnsservrarna har uppdaterats!';
$lang['AdminMain.!success.domain_renewal'] = 'Domänen har förnyats!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Den automatiska domänförnyelsen har uppdaterats!';
$lang['AdminMain.edit.text_registration_date'] = 'Datum för registrering:';
$lang['AdminMain.index.text_date_added'] = 'Datum för införande:';
$lang['AdminMain.index.heading_dateregistration'] = 'Datum för registrering';
$lang['AdminMain.index.heading_registrar'] = 'Registrator';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Domänregistratorn har uppdaterats!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/sv_se/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Välj automatiskt --';
$lang['AdminMain.edit.title_basic_options'] = 'Grundläggande alternativ';
$lang['AdminMain.edit.title_actions'] = 'Åtgärder';
$lang['AdminMain.edit.title_domain_information'] = 'Domäninformation';
$lang['AdminMain.edit.term_years'] = '%1$s År';
$lang['AdminMain.edit.term_year'] = '%1$s År';
$lang['AdminMain.edit.term_months'] = '%1$s Månader';
$lang['AdminMain.edit.term_month'] = '%1$s Månad';
$lang['AdminMain.edit.term_weeks'] = '%1$s Veckor';
$lang['AdminMain.edit.term_week'] = '%1$s Vecka';
$lang['AdminMain.edit.term_days'] = '%1$s Dagar';
$lang['AdminMain.edit.term_day'] = '%1$s Dag';
$lang['AdminMain.edit.text_date_canceled'] = 'Datum för avbokning:';
$lang['AdminMain.edit.text_date_suspended'] = 'Datum för avstängning:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Datum för senaste förnyelse:';
$lang['AdminMain.edit.text_never'] = 'Aldrig';
$lang['AdminMain.edit.text_date_expires'] = 'Datumet löper ut:';
$lang['AdminMain.edit.text_date_renews'] = 'Datumet förnyas:';
$lang['AdminMain.edit.text_date_added'] = 'Skapat datum:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Registrerade år:';
$lang['AdminMain.edit.text_registrar'] = 'Registrator:';
$lang['AdminMain.edit.text_domain'] = 'Domän:';
$lang['AdminMain.edit.field_edit_service'] = 'Redigera tjänst';
$lang['AdminMain.edit.field_activate'] = 'Aktivera';
$lang['AdminMain.edit.field_submit'] = 'Uppdatering';
$lang['AdminMain.edit.field_notify_order'] = 'Skicka e-post med orderbekräftelse när aktiverad';
$lang['AdminMain.edit.field_use_module'] = 'Använd modul';
$lang['AdminMain.edit.field_module'] = 'Modul för registrator';
$lang['AdminMain.edit.field_client'] = 'Kund';
$lang['AdminMain.edit.field_ns5'] = 'Namnserver 5';
$lang['AdminMain.edit.field_ns4'] = 'Namnserver 4';
$lang['AdminMain.edit.field_ns3'] = 'Namnserver 3';
$lang['AdminMain.edit.field_ns2'] = 'Namnserver 2';
$lang['AdminMain.edit.field_ns1'] = 'Namnserver 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Aktivera automatisk förnyelse';
$lang['AdminMain.edit.field_years'] = 'År';
$lang['AdminMain.edit.field_action'] = 'Åtgärder';
$lang['AdminMain.edit.link_viewclient'] = 'Visa kund';
$lang['AdminMain.edit.boxtitle_edit'] = 'Redigera domän: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Kund #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Rabatt:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Sub Totalt:';
$lang['AdminMain.add_confirmation.price'] = 'Pris';
$lang['AdminMain.add_confirmation.qty'] = 'Antal';
$lang['AdminMain.add_confirmation.description'] = 'Beskrivning';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Överföring';
$lang['AdminMain.add_confirmation.type_register'] = 'Registrering';
$lang['AdminMain.add_confirmation.field_edit'] = 'Redigera';
$lang['AdminMain.add_confirmation.field_add'] = 'Lägg till domän';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Uppdatering';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Kupongkod';
$lang['AdminMain.add_confirmation.field_price'] = 'Pris:';
$lang['AdminMain.add_confirmation.field_type'] = 'Typ:';
$lang['AdminMain.add_confirmation.field_years'] = 'År:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domän:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Nej';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ja';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Skicka e-post med orderbekräftelse:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modul för registratorer:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Fakturera inte';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Bifoga till faktura %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Skapa ny faktura';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Faktureringsmetod:';
$lang['AdminMain.add.edit_package_pricing'] = 'Redigera priser';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (förnyas @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Beställning vald';
$lang['AdminMain.add.term_years'] = '%1$s År';
$lang['AdminMain.add.term_year'] = '%1$s År';
$lang['AdminMain.add.term_months'] = '%1$s Månader';
$lang['AdminMain.add.term_month'] = '%1$s Månad';
$lang['AdminMain.add.term_weeks'] = '%1$s Veckor';
$lang['AdminMain.add.term_week'] = '%1$s Vecka';
$lang['AdminMain.add.term_days'] = '%1$s Dagar';
$lang['AdminMain.add.term_day'] = '%1$s Dag';
$lang['AdminMain.add.text_domain_unavailable'] = 'Ej tillgänglig';
$lang['AdminMain.add.text_domain_available'] = 'Tillgänglig';
$lang['AdminMain.add.heading_options'] = 'Alternativ';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domän';
$lang['AdminMain.add.title_registrar_options'] = 'Alternativ för registrator';
$lang['AdminMain.add.title_basic_options'] = 'Grundläggande alternativ';
$lang['AdminMain.add.title_search_results'] = 'Sökresultat';
$lang['AdminMain.add.field_notify_order'] = 'Skicka e-post med orderbekräftelse när aktiverad';
$lang['AdminMain.add.field_use_module'] = 'Tillhandahåll domänen med hjälp av registrarmodulen när den är aktiverad';
$lang['AdminMain.add.field_module'] = 'Modul för registrator';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'År';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Fakturera inte';
$lang['AdminMain.add.field_invoice_method_append'] = 'Lägg till befintlig faktura';
$lang['AdminMain.add.field_invoice_method_create'] = 'Skapa ny faktura';
$lang['AdminMain.add.field_invoice_method'] = 'Faktureringsmetod';
$lang['AdminMain.add.field_submit'] = 'Fortsätta';
$lang['AdminMain.add.field_lookup'] = 'Kontrollera tillgänglighet';
$lang['AdminMain.add.field_add'] = 'Lägg till domän';
$lang['AdminMain.add.field_register'] = 'Register';
$lang['AdminMain.add.field_transfer'] = 'Överföring';
$lang['AdminMain.add.link_viewclient'] = 'Visa kund';
$lang['AdminMain.add.boxtitle_add'] = 'Lägg till domän: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Kund #%1$s';
$lang['AdminMain.index.unparent'] = 'Föräldrafri och återställ priset';
$lang['AdminMain.!error.unsupported_domain'] = 'Domännamnet stöds inte.';
$lang['AdminMain.!success.service_edited'] = 'Domänen har uppdaterats framgångsrikt!';
$lang['AdminMain.!success.domain_add'] = 'Domänen har lagts till framgångsrikt!';
$lang['AdminMain.!success.domain_transfer'] = 'Domänen har överförts framgångsrikt!';
$lang['AdminMain.!success.domain_register'] = 'Domänen har registrerats framgångsrikt!';
$lang['AdminMain.!success.domains_unparented'] = 'De valda domänerna togs bort från sina överordnade tjänster och priset har återställts framgångsrikt!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Domännamn';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Någon';
$lang['AdminMain.domains.action.field_client'] = 'Kund';
$lang['AdminMain.domains.action.field_nameservers'] = 'Namnservrar';
$lang['AdminMain.domains.action.field_years'] = 'År';
$lang['AdminMain.index.field_actionsubmit'] = 'Skicka in';
$lang['AdminMain.index.domain_push_to_client'] = 'Tryck till klient';
$lang['AdminMain.index.update_nameservers'] = 'Uppdatera namnservrar';
$lang['AdminMain.index.domain_renewal'] = 'Förnya domän';
$lang['AdminMain.index.change_auto_renewal'] = 'Ändra förnyelse av bil';
$lang['AdminMain.index.text_off'] = 'Av';
$lang['AdminMain.index.text_on'] = 'På';
$lang['AdminMain.index.text_never'] = 'Aldrig';
$lang['AdminMain.index.no_results'] = 'Det finns inga tjänster med denna status.';
$lang['AdminMain.index.confirm_delete'] = 'Är du säker på att du vill ta bort den här tjänsten?';
$lang['AdminMain.index.option_delete'] = 'Radera';
$lang['AdminMain.index.option_manage'] = 'Hantera';
$lang['AdminMain.index.option_parent'] = 'Förälder';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Ny domän';
$lang['AdminMain.index.category_canceled'] = 'Avbokad';
$lang['AdminMain.index.category_suspended'] = 'Suspenderad';
$lang['AdminMain.index.category_pending'] = 'Pågående';
$lang['AdminMain.index.category_active'] = 'Aktiv';
$lang['AdminMain.index.heading_options'] = 'Alternativ';
$lang['AdminMain.index.heading_datecanceled'] = 'Datum Annullerat';
$lang['AdminMain.index.heading_datesuspended'] = 'Datum uppskjutet';
$lang['AdminMain.index.heading_dateexpires'] = 'Datum som löper ut';
$lang['AdminMain.index.heading_daterenews'] = 'Datum Förnyas';
$lang['AdminMain.index.heading_datecreated'] = 'Skapat datum';
$lang['AdminMain.index.heading_term'] = 'Term';
$lang['AdminMain.index.heading_domain'] = 'Domän';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Tillägg';
$lang['AdminMain.index.boxtitle_domains'] = 'Domäner';
$lang['AdminMain.index.page_title'] = 'Klient #%1$s Domäner';
$lang['AdminMain.!success.domains_pushed'] = 'De valda domänerna har överförts till den nya klienten.';
$lang['AdminMain.!success.update_nameservers'] = 'Domännamnsservrarna har uppdaterats!';
$lang['AdminMain.!success.domain_renewal'] = 'Domänen har förnyats!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Den automatiska domänförnyelsen har uppdaterats!';
$lang['AdminMain.edit.text_registration_date'] = 'Datum för registrering:';
$lang['AdminMain.index.text_date_added'] = 'Datum för införande:';
$lang['AdminMain.index.heading_dateregistration'] = 'Datum för registrering';
$lang['AdminMain.index.heading_registrar'] = 'Registrator';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Domänregistratorn har uppdaterats!';
$lang['AdminMain.edit.field_registration_date'] = 'Ändra registreringsdatum';
$lang['AdminMain.edit.field_expiration_date'] = 'Ändra utgångsdatum';
$lang['AdminMain.!success.change_registration_date'] = 'Registreringsdatumet för domänen har uppdaterats!';
$lang['AdminMain.!success.change_expiration_date'] = 'Domänens utgångsdatum har uppdaterats!';
